# Generated by Django 5.0.4 on 2024-04-03 20:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_quotes", "0004_quote_pub_date"),
    ]

    operations = [
        migrations.AlterField(
            model_name="groupmarkovmodel",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="groupmarkovmodel",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="groupstats",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="groupstats",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="quote",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="quote",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="quotestats",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="quotestats",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="source",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="source",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="sourcegroup",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="sourcegroup",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="sourcemarkovmodel",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="sourcemarkovmodel",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="sourcestats",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="sourcestats",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
    ]
