# Generated by Django 4.1.1 on 2022-10-11 17:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_quotes", "0003_alter_source_slug_alter_sourcegroup_slug"),
    ]

    operations = [
        migrations.AddField(
            model_name="quote",
            name="pub_date",
            field=models.DateTimeField(
                blank=True,
                help_text="When is the earliest time this should appear in random results?",
                null=True,
            ),
        ),
    ]
